import sys
import json

from testwizard.commands_core import CommandBase
from .WaitForSampleResult import WaitForSampleResult


class WaitForSampleCommand(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "WaitForSample")

    def execute(self, x, y, width, height, minSimilarity, timeout, tolerance, distanceMethod, maxDistance):
        if x is None:
            raise Exception("x is required")
        if y is None:
            raise Exception("y is required")
        if width is None:
            raise Exception("width is required")
        if height is None:
            raise Exception("height is required")
        if minSimilarity is None:
            raise Exception("minSimilarity is required")
        if timeout is None:
            raise Exception("timeout is required")
        if tolerance is None:
            raise Exception("tolerance is required")

        requestObj = [x, y, width, height, minSimilarity, timeout, tolerance]
        if distanceMethod is not None:
            requestObj = [x, y, width, height, minSimilarity, timeout, tolerance, distanceMethod]
            if maxDistance is not None:
                requestObj = [x, y, width, height, minSimilarity, timeout, tolerance, distanceMethod, maxDistance]

        result = self.executeCommand(requestObj)

        return WaitForSampleResult(result, "WaitForSample was successful", "WaitForSample failed")



import sys
import json

from testwizard.commands_core import CommandBase
from .CountLastPatternMatchesResult import CountLastPatternMatchesResult


class CountLastPatternMatchesCommand(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "CountLastPatternMatches")

    def execute(self, similarity):
        if similarity is None:
            raise Exception("similarity is required")

        requestObj = [similarity]

        result = self.executeCommand(requestObj)

        return CountLastPatternMatchesResult(result, "CountLastPatternMatches was successful", "CountLastPatternMatches failed")



import sys
import json

from testwizard.commands_core import CommandBase
from .SaveFileResult import SaveFileResult


class SnapShotCommand(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "SnapShot")

    def execute(self, filename, imageFormat, quality):
        if filename is None:
            raise Exception("filename is required")

        if imageFormat is None:
            raise Exception("imageFormat is required")

        requestObj = [filename, imageFormat]

        if quality is not None:
            requestObj = [filename, imageFormat, quality]

        result = self.executeCommand(requestObj)

        return SaveFileResult(result, "SnapShot was successful", "SnapShot failed")



import sys
import json

from testwizard.commands_core import CommandBase
from .WaitForPatternResult import WaitForPatternResult


class WaitForPatternNoMatchCommand(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "WaitForPatternNoMatch")

    def execute(self, filename, minSimilarity, timeout, mode, x, y, width, height):
        if filename is None:
            raise Exception("filename is required")
        if minSimilarity is None:
            raise Exception("minSimilarity is required")
        if timeout is None:
            raise Exception("timeout is required")
        if mode is None:
            raise Exception("mode is required")
        if x is None:
            raise Exception("x is required")
        if y is None:
            raise Exception("y is required")
        if width is None:
            raise Exception("width is required")
        if height is None:
            raise Exception("height is required")

        requestObj = [filename, minSimilarity,
                      timeout, mode, x, y, width, height]

        result = self.executeCommand(requestObj)

        return WaitForPatternResult(result, "WaitForPatternNoMatch was successful", "WaitForPatternNoMatch failed")



import sys
import json

from testwizard.commands_core import CommandBase
from .FilterResult import FilterResult


class FilterColorBlackWhiteCommand(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "FilterColorBlackWhite")

    def execute(self, color, tolerance):
        if color is None:
            raise Exception("color is required")
        if tolerance is None:
            raise Exception("tolerance is required")

        requestObj = [color, tolerance]

        result = self.executeCommand(requestObj)

        return FilterResult(result, "FilterColorBlackWhite was successful", "FilterColorBlackWhite failed")



import sys
import json

from testwizard.commands_core import CommandBase
from testwizard.commands_core.OkResult import OkResult


class SetAttributeOnScreenDisplayCommand(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "SetAttributeOnScreenDisplay")

    def execute(self, attributeType, osdArea,  textColor, backgroundColor, duration):
        if attributeType is None:
            raise Exception("attributeType is required")

        requestObj = [attributeType]
        if osdArea is not None:
            requestObj = [attributeType, osdArea]
            if textColor is not None:
                requestObj = [attributeType, osdArea, textColor]
                if backgroundColor is not None:
                    requestObj = [attributeType, osdArea, textColor, backgroundColor]
                    if duration is not None:
                        requestObj = [attributeType, osdArea, textColor, backgroundColor, duration]

        result = self.executeCommand(requestObj)

        return OkResult(result, "SetAttributeOnScreenDisplay was successful", "SetAttributeOnScreenDisplay failed")



import json
import sys

from testwizard.commands_core.ResultBase import ResultBase

class WaitForColorResult(ResultBase):
    def __init__(self, result, successMessage, failMessage):
        ResultBase.__init__(self, result["time"] >= 0 and result["errorCode"] == 0, successMessage, failMessage)

        self.time = result["time"]
        self.similarity = result["similarity"]
        self.color = Color(result["color"])

        if self.success is True:
            return

        self.message = self.getMessageForErrorCode(self.message, result["errorCode"])

class Color(object):
    def __init__(self, color):
       self.__r = int(color["r"])
       self.__g = int(color["g"])
       self.__b = int(color["b"])

    @property
    def r(self):
        return self.__r

    @property
    def g(self):
        return self.__g

    @property
    def b(self):
        return self.__b



import sys
import json

from testwizard.commands_core import CommandBase
from .CompareResult import CompareResult


class CompareCommand(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "Compare")

    def execute(self, x, y, width, height, filename, tolerance):
        if x is None:
            raise Exception("x is required")
        if y is None:
            raise Exception("y is required")
        if width is None:
            raise Exception("width is required")
        if height is None:
            raise Exception("height is required")
        if filename is None:
            raise Exception("filename is required")
        if tolerance is None:
            raise Exception("tolerance is required")

        requestObj = [x, y, width, height, filename, tolerance]

        result = self.executeCommand(requestObj)

        return CompareResult(result, "compare was successful", "compare failed")



import sys
import json

from testwizard.commands_core import CommandBase
from .FindAllPatternLocationsResult import FindAllPatternLocationsResult


class FindAllPatternLocationsCommand(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "FindAllPatternLocations")

    def execute(self, filename, mode, similarity):
        if filename is None:
            raise Exception("filename is required")
        if mode is None:
            raise Exception("mode is required")
        if similarity is None:
            raise Exception("similarity is required")

        requestObj = [filename, mode, similarity]

        result = self.executeCommand(requestObj)

        return FindAllPatternLocationsResult(result, "FindAllPatternLocations was successful", "FindAllPatternLocations failed")



import sys
import json

from testwizard.commands_core import CommandBase
from .TextOCRResult import TextOCRResult


class TextOCRCommand(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "TextOCR")

    def execute(self, dictionary):
        if dictionary is None:
            raise Exception("dictionary is required")

        requestObj = [dictionary]

        result = self.executeCommand(requestObj)

        return TextOCRResult(result, "TextOCR was successful", "TextOCR failed")



import sys
import json

from testwizard.commands_core import CommandBase
from testwizard.commands_core.SimpleResult import SimpleResult

class StartBackgroundCaptureCommand(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "StartBGCapture")
    
    def execute(self, stepSize, captures):
        if stepSize is None:
            raise Exception("stepSize is required")
        if captures is None:
            raise Exception("captures is required")

        requestObj = [stepSize, captures]

        result = self.executeCommand(requestObj)

        return SimpleResult(result, "StartBackgroundCapture was successful", "StartBackgroundCapture failed")


import sys
import json

from testwizard.commands_core import CommandBase
from .DetectMotionResult import DetectMotionResult

class DetectNoMotionCommand(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "DetectNoMotion")
    
    def execute(self, x, y, width, height, minDifference, timeout, motionDuration, tolerance, distanceMethod, minDistance):
        if x is None:
            raise Exception("x is required")
        if y is None:
            raise Exception("y is required")
        if width is None:
            raise Exception("width is required")
        if height is None:
            raise Exception("height is required")
        if minDifference is None:
            raise Exception("minDifference is required")
        if timeout is None:
            raise Exception("timeout is required")

        requestObj = [x, y, width, height, minDifference, timeout]
        if motionDuration is not None:
            requestObj = [x, y, width, height, minDifference, timeout, motionDuration]
            if tolerance is not None:
                requestObj = [x, y, width, height, minDifference, timeout, motionDuration, tolerance]
                if distanceMethod is not None:
                    requestObj = [x, y, width, height, minDifference, timeout, motionDuration, tolerance, distanceMethod]
                    if minDistance is not None:
                        requestObj = [x, y, width, height, minDifference, timeout, motionDuration, tolerance, distanceMethod, minDistance]

        result = self.executeCommand(requestObj)

        return DetectMotionResult(result, "DetectNoMotion was successful", "DetectNoMotion failed")


import sys
import json

from testwizard.commands_core import CommandBase
from .WaitForColorResult import WaitForColorResult


class WaitForColorCommand(CommandBase):
    def __init__(self, testObject):
        CommandBase.__init__(self, testObject, "WaitForColor")

    def execute(self, x, y, width, height, refColor, tolerance, minSimilarity, timeout):
        if x is None:
            raise Exception("x is required")
        if y is None:
            raise Exception("y is required")
        if width is None:
            raise Exception("width is required")
        if height is None:
            raise Exception("height is required")
        if refColor is None:
            raise Exception("refColor is required")
        if tolerance is None:
            raise Exception("tolerance is required")
        if minSimilarity is None:
            raise Exception("minSimilarity is required")
        if timeout is None:
            raise Exception("timeout is required")

        requestObj = [x, y, width, height, refColor,
                      tolerance, minSimilarity, timeout]

        result = self.executeCommand(requestObj)

        return WaitForColorResult(result, "WaitForColor was successful", "WaitForColor failed")
